myserver-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[myserver-commit] [SCM] GNU MyServer branch, master, updated. 0_9-361-g5


From: Giuseppe Scrivano
Subject: [myserver-commit] [SCM] GNU MyServer branch, master, updated. 0_9-361-g5454284
Date: Fri, 06 Nov 2009 00:14:41 +0000

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU MyServer".

The branch, master has been updated
       via  5454284e8ee015351d807f5ee10f5b985af4b56b (commit)
      from  16ded713f3e44e1677dd2d7b7d0da234fa9f70d9 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------


commit 5454284e8ee015351d807f5ee10f5b985af4b56b
Author: Giuseppe Scrivano <address@hidden>
Date:   Fri Nov 6 01:14:53 2009 +0100

    Fix typo

diff --git a/myserver/src/myserver.cpp b/myserver/src/myserver.cpp
index db4e7d5..25a2e73 100644
--- a/myserver/src/myserver.cpp
+++ b/myserver/src/myserver.cpp
@@ -139,7 +139,7 @@ struct argp_input
   /* If executed as a daemon, write the pid to this file.  */
   const char *pidFileName;
 
   /* Define an alternate location for the configuration files.  */
   const char *confFilesLocation;
 
   /* Specify if the fork server is used.  */
@@ -163,7 +163,7 @@ static struct argp_option options[] =
     {"log", 'l', "location", 0, _("Specify the location (using the format 
protocol://resource) to use as the main log.")},
     {"pidfile", 'p', "file", 0, _("Specify the file where write the PID")},
     {"fork_server", 'f', NULL, 0, _("Specify if use a fork server")},
-    {"cfgdir", CONFIG_OPT, "dir", 0, _("Specify an alternate directory where 
look for configuration files")},
+    {"cfgdir", CONFIG_OPT, "dir", 0, _("Specify an alternative directory where 
look for configuration files")},
     {0}
   };
 
@@ -336,7 +336,7 @@ static MainConfiguration *genMainConf (Server *server, 
const char *arg)
       delete conf;
       return NULL;
     }
-    return conf;
+  return conf;
 }
 
 const char *program_name = NULL;
@@ -606,8 +606,8 @@ int writePidfile (const char* filename)
 /*!
  * Start MyServer in console mode.
  */
- void consoleService (string &mainConf, string &mimeConf, string &vhostConf, 
string &externPath,
-                      MainConfiguration* (*genMainConf) (Server *server, const 
char *arg))
+void consoleService (string &mainConf, string &mimeConf, string &vhostConf, 
string &externPath,
+                     MainConfiguration* (*genMainConf) (Server *server, const 
char *arg))
 {
   Server::getInstance ()->start (mainConf, mimeConf, vhostConf, externPath, 
genMainConf);
 }

-----------------------------------------------------------------------

Summary of changes:
 myserver/src/myserver.cpp |   10 +++++-----
@@ -139,7 +139,7 @@ struct argp_input
   const char *pidFileName;
 
-  /* Define an alternate location for the configuration files.  */
+  /* Define an alternative location for the configuration files.  */
   const char *confFilesLocation;
 
 1 files changed, 5 insertions(+), 5 deletions(-)


hooks/post-receive
-- 
GNU MyServer




reply via email to

[Prev in Thread] Current Thread [Next in Thread]